@@ -98,6 +98,6 @@ plot_scatter<-function(sim=temp.interpolated,
   plot(p)
 
   if(plot.save){
-    p+ggsave(filename = file_name,height = height,width = width)
+    ggsave(filename = file_name,height = height,width = width)
   }
 }
