@@ -97,6 +97,6 @@ plot_ts<-function(sim=temp.interpolated,
   plot(p)
 
   if(plot.save){
-    p+ggsave(filename = file_name,height = height,width = width)
+    ggsave(filename = file_name,height = height,width = width)
   }
 }
